@@ -25,7 +25,6 @@ latex.dialogs
 import logging
 import tempfile
 import os.path
-import time
 import string
 
 from gi.repository import Gtk, GdkPixbuf
@@ -41,43 +40,7 @@ from .listing import LanguagesParser
 
 from . import LaTeXSource
 
-class AbstractProxy(object):
-    """
-    This may simplify the use of a widget and it serves for state saving
-    using the plugins preferences.
-    """
-    def __init__(self, widget, key):
-        """
-        @param widget: the widget to proxy
-        @param key: a preferences key to use for state saving
-        """
-        self._widget = widget
-        self._key = key
-        self._preferences = Preferences()
-
-    def restore(self, default):
-        """
-        Restore the last state of the proxied widget
-
-        @param default: a default value if no state is found
-        """
-        raise NotImplementedError
-
-    def save(self):
-        """
-        Save the state of the proxied widget
-        """
-        self._preferences.set(self._key, self.value)
-
-    @property
-    def value(self):
-        """
-        @return: the current value of the proxied widget
-        """
-        raise NotImplementedError
-
-
-class ComboBoxProxy(AbstractProxy):
+class ComboBoxProxy:
     """
     This proxies a ComboBox widget:
 
@@ -88,7 +51,9 @@ class ComboBoxProxy(AbstractProxy):
     ...
     """
     def __init__(self, widget, key):
-        AbstractProxy.__init__(self, widget, key)
+        self._widget = widget
+        self._key = key
+        self._preferences = Preferences()
 
         self._store = Gtk.ListStore(str, str)            # value, label
         self._widget.set_model(self._store)
@@ -115,9 +80,8 @@ class ComboBoxProxy(AbstractProxy):
         self._widget.connect("changed", self._on_changed)
 
     def _on_changed(self, combobox):
-        self.save()
+        self._preferences.set(self._key, self.value)
 
-    #@accepts(object, String, String, bool)
     def add_option(self, value, label, show_value=True):
         """
         Add an option to the widget
@@ -127,15 +91,13 @@ class ComboBoxProxy(AbstractProxy):
         """
         self._options.append((value, label))
 
-        label_markup = ""
-
         if show_value:
             if not value is None and len(value) > 0:
-                label_markup = "%s <span color='%s'>%s</span>" % (value, self._preferences.get("light-foreground-color"), label)
+                label_markup = "%s <span color='%s'>%s</span>" % (value, self._preferences.get("light-foreground-color"), _(label))
             else:
-                label_markup = "<span color='%s'>%s</span>" % (self._preferences.get("light-foreground-color"), label)
+                label_markup = "<span color='%s'>%s</span>" % (self._preferences.get("light-foreground-color"), _(label))
         else:
-            label_markup = label
+            label_markup = _(label)
 
         self._store.append([value, label_markup])
 
@@ -144,23 +106,6 @@ class ComboBoxProxy(AbstractProxy):
         index = self._widget.get_active()
         return self._options[index][0]
 
-
-class EntryProxy(AbstractProxy):
-    def __init__(self, widget, key):
-        AbstractProxy.__init__(self, widget, key)
-
-    def restore(self, default=None):
-        if default != None:
-            txt = default
-        else:
-            txt = self._preferences.get(self._key, default)
-        self._widget.set_text(txt)
-
-    @property
-    def value(self):
-        return self._widget.get_text()
-
-
 class ChooseMasterDialog(GladeInterface):
     """
     Dialog for choosing a master file to a LaTeX fragment file
@@ -352,10 +297,13 @@ class NewDocumentDialog(GladeInterface):
             folder = Folder(preferences.TEMPLATE_DIR)
 
             templates = folder.files
+            default_template_path = Resources().get_data_file("templates")
+            folder = Folder(default_template_path)
+            templates.extend(folder.files)
             templates.sort()
             for template in templates:
                 self._proxy_template.add_option(template.path, template.shortbasename, show_value=False)
-            self._proxy_template.restore("Default")
+            self._proxy_template.restore(os.path.join(default_template_path,"Default.template"))
 
             #
             # metadata
@@ -373,14 +321,14 @@ class NewDocumentDialog(GladeInterface):
             document_classes = environment.document_classes
             document_classes.sort(key=lambda x: x.name.lower())
             for c in document_classes:
-                self._proxy_document_class.add_option(c.name, c.label)
+                self._proxy_document_class.add_option(c.name, _(c.label))
             self._proxy_document_class.restore("article")
 
             #
             # paper
             #
             self._proxy_paper_size = ComboBoxProxy(self.find_widget("comboPaperSize"), "RecentPaperSize")
-            self._proxy_paper_size.add_option("", "Default")
+            self._proxy_paper_size.add_option("", _("Default"))
             for size, label in self._PAPER_SIZES:
                 self._proxy_paper_size.add_option(size, label)
             self._proxy_paper_size.restore("")
@@ -401,7 +349,7 @@ class NewDocumentDialog(GladeInterface):
             #
             self._proxy_font_family = ComboBoxProxy(self.find_widget("comboFontFamily"), "RecentDefaultFontFamily")
             for command, label in self._DEFAULT_FONT_FAMILIES:
-                self._proxy_font_family.add_option(command, label, False)
+                self._proxy_font_family.add_option(command, _(label), False)
             self._proxy_font_family.restore("\\rmdefault")
 
 
@@ -422,11 +370,11 @@ class NewDocumentDialog(GladeInterface):
             language_definitions = environment.language_definitions
             language_definitions.sort(key=lambda x: x.name.lower())
             for l in language_definitions:
-                self._proxy_babel.add_option(l.name, l.label)
+                self._proxy_babel.add_option(l.name, _(l.label))
 
             try:
                 self._proxy_babel.restore(self._LOCALE_MAPPINGS[environment.language_code])
-            except Exception, e:
+            except Exception as e:
                 self._log.error("Failed to guess babel package: %s" % e)
                 self._proxy_babel.restore("english")
 
@@ -632,7 +580,7 @@ class UseBibliographyDialog(GladeInterface, PreviewRenderer):
             self._comboStyle.set_model(self._storeStyle)
 
             try:
-                recent = styles.index(Preferences().get("RecentBibtexStyle", "plain"))
+                recent = styles.index(Preferences().get("recent-bibtex-style"))
             except ValueError:
                 recent = 0
             self._comboStyle.set_active(recent)
@@ -945,6 +893,7 @@ class InsertListingDialog(GladeInterface):
 
             lstset = ""
             options = ""
+            extra = r',basicstyle=\small\ttfamily,breaklines=true,showtabs=false,showspaces=false,breakatwhitespace=true'
 
             language = self._storeLanguages[self._comboLanguage.get_active()][0]
             try:
@@ -954,9 +903,9 @@ class InsertListingDialog(GladeInterface):
 
             if self._dialectsEnabled and len(dialect):
                 # we need the lstset command
-                lstset = "\\lstset{language=[%s]%s}\n" % (dialect, language)
+                lstset = "\\lstset{language=[%s]%s%s}\n" % (dialect, language, extra)
             else:
-                options = "[language=%s]" % language
+                options = "[language=%s%s]" % (language, extra)
 
 
             if self._checkFile.get_active():
@@ -987,7 +936,7 @@ class InsertListingDialog(GladeInterface):
             parser = LanguagesParser()
             parser.parse(self._languages, Resources().get_data_file("listings.xml"))
 
-            recentLanguage = Preferences().get("RecentListingLanguage", "Java")
+            recentLanguage = Preferences().get("recent-listing-language")
 
             self._storeLanguages = Gtk.ListStore(str)
             recentLanguageIndex = 0
@@ -1105,15 +1054,15 @@ class BuildImageDialog(GladeInterface):
     def _getDialog(self):
         if not self._dialog:
             self._dialog = self.find_widget("dialogRenderImage")
-            self.find_widget("table").set_col_spacing(0, 20)
+            self.find_widget("grid1").set_column_spacing(20)
 
             # PNG mode
 
             self._storeMode = Gtk.ListStore(str, int)    # label, mode constant
-            self._storeMode.append(["Monochrome", ImageToolGenerator.PNG_MODE_MONOCHROME])
-            self._storeMode.append(["Grayscale", ImageToolGenerator.PNG_MODE_GRAYSCALE])
-            self._storeMode.append(["RGB", ImageToolGenerator.PNG_MODE_RGB])
-            self._storeMode.append(["RGBA", ImageToolGenerator.PNG_MODE_RGBA])
+            self._storeMode.append([_("Monochrome"), ImageToolGenerator.PNG_MODE_MONOCHROME])
+            self._storeMode.append([_("Grayscale"), ImageToolGenerator.PNG_MODE_GRAYSCALE])
+            self._storeMode.append([_("RGB"), ImageToolGenerator.PNG_MODE_RGB])
+            self._storeMode.append([_("RGBA"), ImageToolGenerator.PNG_MODE_RGBA])
 
             self._comboMode = self.find_widget("comboMode")
             self._comboMode.set_model(self._storeMode)
@@ -1125,11 +1074,11 @@ class BuildImageDialog(GladeInterface):
             # anti-alias
 
             self._storeAntialias = Gtk.ListStore(str, int)    # label, factor
-            self._storeAntialias.append(["Off", 0])
-            self._storeAntialias.append(["1x", 1])
-            self._storeAntialias.append(["2x", 2])
-            self._storeAntialias.append(["4x", 4])
-            self._storeAntialias.append(["8x", 8])
+            self._storeAntialias.append([_("Off"), 0])
+            self._storeAntialias.append([_("1×"), 1])
+            self._storeAntialias.append([_("2×"), 2])
+            self._storeAntialias.append([_("4×"), 4])
+            self._storeAntialias.append([_("8×"), 8])
 
             self._comboAntialias = self.find_widget("comboAntialias")
             self._comboAntialias.set_model(self._storeAntialias)
